* Replication Materials for *
* Bellemare, Marc F. (2012), "As You Sow, So Shall You Reap: *
* The Welfare Impacts of Contract Farming," World Development *

* Instructions: Install and Run this Code in Your C:\ Folder *

* Marc F. Bellemare *
* marc.bellemare@duke.edu *

clear
drop _all
set mem 256m

use "C:\BellemareContractFarmingWorldDevelopment.dta"

replace k1_accepte = 0 if k1_accepte==2
replace k1_invest = k1_invest/2000

tabulate id_fok, gen(id_fok)
tabulate k2

gen id_fok_k2 = id_fok*10 + k2

gen wtp = .

replace wtp = k1_invest if k1_accepte==1
replace wtp = 0 if k1_accepte==0


gen k1_1 = 1 if k1_invest==12.5 & k1_accepte==1
replace k1_1 = 0 if k1_invest~=12.5 | k1_accepte~=1

gen k1_2 = 1 if k1_invest==25 & k1_accepte==1
replace k1_2 = 0 if k1_invest~=25 | k1_accepte~=1

gen k1_3 = 1 if k1_invest==37.5 & k1_accepte==1
replace k1_3 = 0 if k1_invest~=37.5 | k1_accepte~=1

gen k1_4 = 1 if k1_invest==50 & k1_accepte==1
replace k1_4 = 0 if k1_invest~=50 | k1_accepte~=1

gen k1_5 = 1 if k1_invest==62.5 & k1_accepte==1
replace k1_5 = 0 if k1_invest~=62.5 | k1_accepte~=1

gen k1_6 = 1 if k1_invest==75 & k1_accepte==1
replace k1_6 = 0 if k1_invest~=75 | k1_accepte~=1

gen k1_0 = 1 - (k1_1 + k1_2 + k1_3 + k1_4 + k1_5 + k1_6)

egen mean_income = mean(income_endo)
egen mean_income_pc = mean(income_pc)
egen mean_income_ae = mean(income_ae)
egen mean_income_exo = mean(income_exo)

log using "C:\BellemareContractFarmingWorldDevelopment", replace



* Table 3 *

mean hhsize depr single female migrant age educ ag_exp farm_org fady income_endo income_pc income_ae income_exo soudure fin_loan_f fin_loan_inf shock_hhsick shock_crtheft shock_crsick wrk_cap assets land_tot if cf==0 [pweight=weight]

mean hhsize depr single female migrant age educ ag_exp farm_org fady income_endo income_pc income_ae income_exo soudure fin_loan_f fin_loan_inf shock_hhsick shock_crtheft shock_crsick wrk_cap assets land_tot if cf==1 [pweight=weight]



* Table 4 *

sort cf
ttest hhsize if wtp~=., by(cf)
ttest depr if wtp~=., by(cf)
ttest female if wtp~=., by(cf) 
ttest single if wtp~=., by(cf) 
ttest migrant if wtp~=., by(cf) 
ttest age if wtp~=., by(cf) 
ttest educ if wtp~=., by(cf) 
ttest ag_exp if wtp~=., by(cf) 
ttest farm_org if wtp~=., by(cf) 
ttest fady if wtp~=., by(cf) 
ttest income_endo if wtp~=., by(cf) 
ttest income_pc if wtp~=., by(cf) 
ttest income_ae if wtp~=., by(cf) 
ttest income_exo if wtp~=., by(cf) 
ttest soudure if wtp~=., by(cf) 
ttest fin_loan_f if wtp~=., by(cf)
ttest fin_loan_inf if wtp~=., by(cf)
ttest shock_hhsick if wtp~=., by(cf)
ttest shock_crtheft if wtp~=., by(cf)
ttest shock_crsick if wtp~=., by(cf)

ttest wrk_cap if wtp~=., by(cf) 
ttest assets if wtp~=., by(cf) 
ttest land_tot if wtp~=., by(cf)



* Figure 2 *

label variable ln_income "Log(Income)"

kdensity ln_income if cf==0 & wtp~=., w(0.5) epanechnikov addplot(kdensity ln_income if cf==1 & wtp~=., w(0.5) epanechnikov lpattern(dash)) title(Distribution of Income) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF"))



* Figure 3 *

label variable ln_income_ae "Log(Income Per Adult Equivalent)"

kdensity ln_income_ae if cf==0 & wtp~=., w(0.5) epanechnikov addplot(kdensity ln_income_ae if cf==1 & wtp~=., w(0.5) epanechnikov lpattern(dash)) title(Distribution of Income Per Adult Equivalent) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF"))



* Figure 4 *

label variable ln_income_exo "Log(Income Net of CF Revenue)"

kdensity ln_income_exo if cf==0 & wtp~=., w(0.5) epanechnikov addplot(kdensity ln_income_exo if cf==1 & wtp~=., w(0.5) epanechnikov lpattern(dash)) title(Distribution of Income Net of CF Revenue) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF"))



* Table 5 *

probit cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight]
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6



* Table 6 *

xi: treatreg ln_income hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first
test [cf]k1_1 [cf]k1_2 [cf]k1_3 [cf]k1_4 [cf]k1_5 [cf]k1_6
mfx, dyex varlist(cf)

xi: reg ln_income hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot cf fiv_2-fiv_6 [pweight=weight]
mfx, dyex varlist(cf)



* Table 7 *

xi: treatreg ln_income_ae hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) 
test [cf]k1_1 [cf]k1_2 [cf]k1_3 [cf]k1_4 [cf]k1_5 [cf]k1_6
mfx, dyex varlist(cf)

xi: reg ln_income_ae hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot cf fiv_2-fiv_6 [pweight=weight]
mfx, dyex varlist(cf)



* Table 8 *

xi: treatreg ln_income_exo hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) 
test [cf]k1_1 [cf]k1_2 [cf]k1_3 [cf]k1_4 [cf]k1_5 [cf]k1_6
mfx, dyex varlist(cf)

xi: reg ln_income_exo hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot cf fiv_2-fiv_6 [pweight=weight]
mfx, dyex varlist(cf)



* Descriptive Statistics *

mean income* if wtp~=. [pweight=weight], level(99)


* Table A1 *

pscore cf hhsize depr single female migrant age educ ag_exp fady wrk_cap assets fiv_4 fiv_5 [pweight=weight], pscore(score)

xi: reg ln_income hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 score [pweight=weight]
mfx, dyex varlist(score)

xi: reg ln_income hhsize depr single female migrant age educ ag_exp fady wrk_cap assets fiv_4 fiv_5 score [pweight=weight]
mfx, dyex varlist(score)



* Not Shown in Paper, But Discussed in Section 4b *

gen ln_income_lv = ln((inc_lvstock+0.001)/100)
gen ln_income_lb = ln((inc_labor+0.001)/100)
gen ln_income_nf = ln((inc_nfe+0.001)/100)
gen ln_income_ag = ln((inc_agric+0.001)/100)

xi: treatreg ln_income_lv hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first
mfx, dyex varlist(cf)
xi: treatreg ln_income_lb hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first
mfx, dyex varlist(cf)
xi: treatreg ln_income_nf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first
mfx, dyex varlist(cf)
xi: treatreg ln_income_ag hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first
mfx, dyex varlist(cf)

log close

view "C:\BellemareContractFarmingWorldDevelopment.smcl"



